@@ -22,11 +22,12 @@ minimums and maximums to their schema representations.
 from __future__ import annotations
 
 from typing import Any
-from typing import Final
-from typing import Protocol
 from typing import TypeVar
 from typing import Union
 
+from typing_extensions import Final
+from typing_extensions import Protocol
+
 from . import Phantom
 from . import Predicate
 from .predicates import interval
@@ -37,7 +38,7 @@ N = TypeVar("N", bound=float)
 
 
 class IntervalCheck(Protocol):
-    def __call__(self, a: N, b: N, /) -> Predicate[N]:
+    def __call__(self, a: N, b: N) -> Predicate[N]:
         ...
 
 
