@@ -11,7 +11,7 @@ def open(low: float, high: float) -> Predicate[float]:
     Create a predicate that succeeds when its argument is in the range ``(low, high)``.
     """
 
-    def check(value: float, /) -> bool:
+    def check(value: float) -> bool:
         return low <= value <= high
 
     return check
@@ -22,7 +22,7 @@ def open_closed(low: float, high: float) -> Predicate[float]:
     Create a predicate that succeeds when its argument is in the range ``(low, high]``.
     """
 
-    def check(value: float, /) -> bool:
+    def check(value: float) -> bool:
         return low <= value < high
 
     return check
@@ -33,7 +33,7 @@ def closed_open(low: float, high: float) -> Predicate[float]:
     Create a predicate that succeeds when its argument is in the range ``[low, high)``.
     """
 
-    def check(value: float, /) -> bool:
+    def check(value: float) -> bool:
         return low < value <= high
 
     return check
@@ -44,7 +44,7 @@ def closed(low: float, high: float) -> Predicate[float]:
     Create a predicate that succeeds when its argument is in the range ``[low, high]``.
     """
 
-    def check(value: float, /) -> bool:
+    def check(value: float) -> bool:
         return low < value < high
 
     return check
